{
    "$graph": [
        {
            "class": "Workflow",
            "label": "umi molecular alignment fastq workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/library_name"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/platform"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/platform_unit"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/read1_fastq"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/read2_fastq"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/read_structure"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": "string",
                    "id": "#main/sample_name"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/target_intervals"
                }
            ],
            "steps": [
                {
                    "run": "#molecular_alignment.cwl",
                    "in": [
                        {
                            "source": "#main/fastq_to_bam/bam",
                            "id": "#main/alignment_workflow/bam"
                        },
                        {
                            "source": "#main/read_structure",
                            "id": "#main/alignment_workflow/read_structure"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/alignment_workflow/reference"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/alignment_workflow/sample_name"
                        },
                        {
                            "source": "#main/target_intervals",
                            "id": "#main/alignment_workflow/target_intervals"
                        }
                    ],
                    "out": [
                        "#main/alignment_workflow/aligned_cram",
                        "#main/alignment_workflow/adapter_histogram",
                        "#main/alignment_workflow/duplex_seq_metrics"
                    ],
                    "id": "#main/alignment_workflow"
                },
                {
                    "scatter": [
                        "#main/fastq_to_bam/read1_fastq",
                        "#main/fastq_to_bam/read2_fastq",
                        "#main/fastq_to_bam/library_name",
                        "#main/fastq_to_bam/platform_unit",
                        "#main/fastq_to_bam/platform"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#fastq_to_bam.cwl",
                    "in": [
                        {
                            "source": "#main/library_name",
                            "id": "#main/fastq_to_bam/library_name"
                        },
                        {
                            "source": "#main/platform",
                            "id": "#main/fastq_to_bam/platform"
                        },
                        {
                            "source": "#main/platform_unit",
                            "id": "#main/fastq_to_bam/platform_unit"
                        },
                        {
                            "source": "#main/read1_fastq",
                            "id": "#main/fastq_to_bam/read1_fastq"
                        },
                        {
                            "source": "#main/read2_fastq",
                            "id": "#main/fastq_to_bam/read2_fastq"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/fastq_to_bam/sample_name"
                        }
                    ],
                    "out": [
                        "#main/fastq_to_bam/bam"
                    ],
                    "id": "#main/fastq_to_bam"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/alignment_workflow/adapter_histogram",
                    "id": "#main/adapter_histogram"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "outputSource": "#main/alignment_workflow/aligned_cram",
                    "id": "#main/aligned_cram"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/alignment_workflow/duplex_seq_metrics",
                    "id": "#main/duplex_seq_metrics"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "umi molecular alignment workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#molecular_alignment.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#molecular_alignment.cwl/read_structure"
                },
                {
                    "type": "string",
                    "id": "#molecular_alignment.cwl/reference"
                },
                {
                    "type": "string",
                    "id": "#molecular_alignment.cwl/sample_name"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#molecular_alignment.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#molecular_alignment.cwl/align/adapter_metrics",
                    "id": "#molecular_alignment.cwl/adapter_histogram"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "outputSource": "#molecular_alignment.cwl/index_cram/indexed_cram",
                    "id": "#molecular_alignment.cwl/aligned_cram"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#molecular_alignment.cwl/collect_duplex_seq_metrics/duplex_seq_metrics",
                    "id": "#molecular_alignment.cwl/duplex_seq_metrics"
                }
            ],
            "steps": [
                {
                    "scatter": "#molecular_alignment.cwl/align/bam",
                    "run": "#umi_alignment.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/bam",
                            "id": "#molecular_alignment.cwl/align/bam"
                        },
                        {
                            "source": "#molecular_alignment.cwl/read_structure",
                            "id": "#molecular_alignment.cwl/align/read_structure"
                        },
                        {
                            "source": "#molecular_alignment.cwl/reference",
                            "id": "#molecular_alignment.cwl/align/reference"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/align/aligned_bam",
                        "#molecular_alignment.cwl/align/adapter_metrics"
                    ],
                    "id": "#molecular_alignment.cwl/align"
                },
                {
                    "run": "#realign.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/call_molecular_consensus/consensus_bam",
                            "id": "#molecular_alignment.cwl/align_consensus/bam"
                        },
                        {
                            "source": "#molecular_alignment.cwl/reference",
                            "id": "#molecular_alignment.cwl/align_consensus/reference"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/align_consensus/consensus_aligned_bam"
                    ],
                    "id": "#molecular_alignment.cwl/align_consensus"
                },
                {
                    "run": "#bam_to_cram.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/clip_overlap/clipped_bam",
                            "id": "#molecular_alignment.cwl/bam_to_cram/bam"
                        },
                        {
                            "source": "#molecular_alignment.cwl/reference",
                            "id": "#molecular_alignment.cwl/bam_to_cram/reference"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/bam_to_cram/cram"
                    ],
                    "id": "#molecular_alignment.cwl/bam_to_cram"
                },
                {
                    "run": "#call_molecular_consensus.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/group_reads_by_umi/grouped_bam",
                            "id": "#molecular_alignment.cwl/call_molecular_consensus/bam"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/call_molecular_consensus/consensus_bam"
                    ],
                    "id": "#molecular_alignment.cwl/call_molecular_consensus"
                },
                {
                    "run": "#clip_overlap.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/filter_consensus/filtered_bam",
                            "id": "#molecular_alignment.cwl/clip_overlap/bam"
                        },
                        {
                            "source": "#molecular_alignment.cwl/reference",
                            "id": "#molecular_alignment.cwl/clip_overlap/reference"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/clip_overlap/clipped_bam"
                    ],
                    "id": "#molecular_alignment.cwl/clip_overlap"
                },
                {
                    "run": "#duplex_seq_metrics.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/group_reads_by_umi/grouped_bam",
                            "id": "#molecular_alignment.cwl/collect_duplex_seq_metrics/bam"
                        },
                        {
                            "source": "#molecular_alignment.cwl/sample_name",
                            "id": "#molecular_alignment.cwl/collect_duplex_seq_metrics/description"
                        },
                        {
                            "source": "#molecular_alignment.cwl/target_intervals",
                            "id": "#molecular_alignment.cwl/collect_duplex_seq_metrics/intervals"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/collect_duplex_seq_metrics/duplex_seq_metrics"
                    ],
                    "id": "#molecular_alignment.cwl/collect_duplex_seq_metrics"
                },
                {
                    "run": "#filter_consensus.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/align_consensus/consensus_aligned_bam",
                            "id": "#molecular_alignment.cwl/filter_consensus/bam"
                        },
                        {
                            "source": "#molecular_alignment.cwl/reference",
                            "id": "#molecular_alignment.cwl/filter_consensus/reference"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/filter_consensus/filtered_bam"
                    ],
                    "id": "#molecular_alignment.cwl/filter_consensus"
                },
                {
                    "run": "#group_reads.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/merge/merged_bam",
                            "id": "#molecular_alignment.cwl/group_reads_by_umi/bam"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/group_reads_by_umi/grouped_bam"
                    ],
                    "id": "#molecular_alignment.cwl/group_reads_by_umi"
                },
                {
                    "run": "#index_cram.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/bam_to_cram/cram",
                            "id": "#molecular_alignment.cwl/index_cram/cram"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/index_cram/indexed_cram"
                    ],
                    "id": "#molecular_alignment.cwl/index_cram"
                },
                {
                    "run": "#merge_bams.cwl",
                    "in": [
                        {
                            "source": "#molecular_alignment.cwl/align/aligned_bam",
                            "id": "#molecular_alignment.cwl/merge/bams"
                        }
                    ],
                    "out": [
                        "#molecular_alignment.cwl/merge/merged_bam"
                    ],
                    "id": "#molecular_alignment.cwl/merge"
                }
            ],
            "id": "#molecular_alignment.cwl"
        },
        {
            "class": "Workflow",
            "label": "umi per-lane alignment subworkflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#umi_alignment.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#umi_alignment.cwl/read_structure"
                },
                {
                    "type": "string",
                    "id": "#umi_alignment.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#umi_alignment.cwl/mark_illumina_adapters/metrics",
                    "id": "#umi_alignment.cwl/adapter_metrics"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputSource": "#umi_alignment.cwl/align/aligned_bam",
                    "id": "#umi_alignment.cwl/aligned_bam"
                }
            ],
            "steps": [
                {
                    "run": "#umi_align.cwl",
                    "in": [
                        {
                            "source": "#umi_alignment.cwl/mark_illumina_adapters/marked_bam",
                            "id": "#umi_alignment.cwl/align/bam"
                        },
                        {
                            "source": "#umi_alignment.cwl/reference",
                            "id": "#umi_alignment.cwl/align/reference"
                        }
                    ],
                    "out": [
                        "#umi_alignment.cwl/align/aligned_bam"
                    ],
                    "id": "#umi_alignment.cwl/align"
                },
                {
                    "run": "#extract_umis.cwl",
                    "in": [
                        {
                            "source": "#umi_alignment.cwl/bam",
                            "id": "#umi_alignment.cwl/extract_umis/bam"
                        },
                        {
                            "source": "#umi_alignment.cwl/read_structure",
                            "id": "#umi_alignment.cwl/extract_umis/read_structure"
                        }
                    ],
                    "out": [
                        "#umi_alignment.cwl/extract_umis/umi_extracted_bam"
                    ],
                    "id": "#umi_alignment.cwl/extract_umis"
                },
                {
                    "run": "#mark_illumina_adapters.cwl",
                    "in": [
                        {
                            "source": "#umi_alignment.cwl/extract_umis/umi_extracted_bam",
                            "id": "#umi_alignment.cwl/mark_illumina_adapters/bam"
                        }
                    ],
                    "out": [
                        "#umi_alignment.cwl/mark_illumina_adapters/marked_bam",
                        "#umi_alignment.cwl/mark_illumina_adapters/metrics"
                    ],
                    "id": "#umi_alignment.cwl/mark_illumina_adapters"
                }
            ],
            "id": "#umi_alignment.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "BAM to CRAM conversion",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-C"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                }
            ],
            "stdout": "$(inputs.name)",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bam_to_cram.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "final.cram",
                    "id": "#bam_to_cram.cwl/name"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#bam_to_cram.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bam_to_cram.cwl/cram",
                    "outputBinding": {
                        "glob": "$(inputs.name)"
                    }
                }
            ],
            "id": "#bam_to_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "call molecular consensus",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/fgbio-0.5.0.jar",
                "CallMolecularConsensusReads"
            ],
            "arguments": [
                "--error-rate-pre-umi",
                "45",
                "--error-rate-post-umi",
                "30",
                "--min-input-base-quality",
                "30",
                "--min-reads",
                "1",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/consensus_unaligned.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#call_molecular_consensus.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "consensus_unaligned.bam"
                    },
                    "id": "#call_molecular_consensus.cwl/consensus_bam"
                }
            ],
            "id": "#call_molecular_consensus.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "clip overlapping reads",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/fgbio-0.5.0.jar",
                "ClipBam"
            ],
            "arguments": [
                "--soft-clip",
                "false",
                "--clip-overlapping-reads",
                "true",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/clipped.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#clip_overlap.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--ref"
                    },
                    "id": "#clip_overlap.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "clipped.bam"
                    },
                    "id": "#clip_overlap.cwl/clipped_bam"
                }
            ],
            "id": "#clip_overlap.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect duplex seq metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/fgbio-0.5.0.jar",
                "CollectDuplexSeqMetrics"
            ],
            "arguments": [
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/duplex_seq.metrics"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 1000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#duplex_seq_metrics.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--description"
                    },
                    "id": "#duplex_seq_metrics.cwl/description"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--intervals"
                    },
                    "id": "#duplex_seq_metrics.cwl/intervals"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "duplex_seq.metrics.*"
                    },
                    "id": "#duplex_seq_metrics.cwl/duplex_seq_metrics"
                }
            ],
            "id": "#duplex_seq_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "extract umis from bam",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/fgbio-0.5.0.jar",
                "ExtractUmisFromBam"
            ],
            "arguments": [
                "--molecular-index-tags",
                "ZA",
                "ZB",
                "--single-tag",
                "RX",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/umi_extracted.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#extract_umis.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "prefix": "--read-structure"
                    },
                    "id": "#extract_umis.cwl/read_structure"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "umi_extracted.bam"
                    },
                    "id": "#extract_umis.cwl/umi_extracted_bam"
                }
            ],
            "id": "#extract_umis.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "fastq to bam",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/picard/picard.jar",
                "FastqToSam"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/unaligned.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "LIBRARY_NAME=",
                        "position": 4
                    },
                    "id": "#fastq_to_bam.cwl/library_name"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "PLATFORM=",
                        "position": 6
                    },
                    "id": "#fastq_to_bam.cwl/platform"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "PLATFORM_UNIT=",
                        "position": 5
                    },
                    "id": "#fastq_to_bam.cwl/platform_unit"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "FASTQ=",
                        "position": 1
                    },
                    "id": "#fastq_to_bam.cwl/read1_fastq"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "FASTQ2=",
                        "position": 2
                    },
                    "id": "#fastq_to_bam.cwl/read2_fastq"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "SAMPLE_NAME=",
                        "position": 3
                    },
                    "id": "#fastq_to_bam.cwl/sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "unaligned.bam"
                    },
                    "id": "#fastq_to_bam.cwl/bam"
                }
            ],
            "id": "#fastq_to_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "filter consensus reads",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/fgbio-0.5.0.jar",
                "FilterConsensusReads"
            ],
            "arguments": [
                "--min-reads",
                "10",
                "5",
                "3",
                "--max-read-error-rate",
                "0.05",
                "--max-base-error-rate",
                "0.1",
                "--min-base-quality",
                "50",
                "--max-no-call-fraction",
                "0.05",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/consensus_filtered.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#filter_consensus.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--ref"
                    },
                    "id": "#filter_consensus.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "consensus_filtered.bam"
                    },
                    "id": "#filter_consensus.cwl/filtered_bam"
                }
            ],
            "id": "#filter_consensus.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "group reads by umi",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/fgbio-0.5.0.jar",
                "GroupReadsByUmi"
            ],
            "arguments": [
                "--strategy",
                "paired",
                "--assign-tag",
                "MI",
                "--raw-tag",
                "RX",
                "--min-map-q",
                "10",
                "--edits",
                "1",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/umi_grouped.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    },
                    "id": "#group_reads.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "umi_grouped.bam"
                    },
                    "id": "#group_reads.cwl/grouped_bam"
                }
            ],
            "id": "#group_reads.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index cram",
            "arguments": [
                "cp",
                "$(inputs.cram.path)",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                "$(runtime.outdir)/$(inputs.cram.basename).crai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "ln",
                "-s",
                "$(inputs.cram.basename).crai",
                "$(runtime.outdir)/$(inputs.cram.nameroot).crai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_cram.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.cram.basename)"
                    },
                    "id": "#index_cram.cwl/indexed_cram"
                }
            ],
            "id": "#index_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "fastq to bam",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/picard/picard.jar",
                "MarkIlluminaAdapters"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/marked.bam"
                },
                "METRICS=",
                {
                    "valueFrom": "$(runtime.outdir)/adapter_metrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT=",
                        "position": 1
                    },
                    "id": "#mark_illumina_adapters.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "marked.bam"
                    },
                    "id": "#mark_illumina_adapters.cwl/marked_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "adapter_metrics.txt"
                    },
                    "id": "#mark_illumina_adapters.cwl/metrics"
                }
            ],
            "id": "#mark_illumina_adapters.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Sambamba: merge",
            "baseCommand": [
                "/usr/bin/sambamba_merge"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bisulfite"
                }
            ],
            "arguments": [
                "$(runtime.cores)",
                "$(runtime.outdir)/merged.bam"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#merge_bams.cwl/bams"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputBinding": {
                        "glob": "merged.bam"
                    },
                    "id": "#merge_bams.cwl/merged_bam"
                }
            ],
            "id": "#merge_bams.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "umi realignment",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/umi_realignment.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "coresMin": 8
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "arguments": [
                {
                    "position": 3,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#realign.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#realign.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "realigned.bam"
                    },
                    "id": "#realign.cwl/consensus_aligned_bam"
                }
            ],
            "id": "#realign.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "umi alignment",
            "baseCommand": [
                "/bin/bash",
                "/usr/bin/umi_alignment.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "coresMin": 8
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/dna-alignment"
                }
            ],
            "arguments": [
                {
                    "position": 3,
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#umi_align.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#umi_align.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "aligned.bam"
                    },
                    "id": "#umi_align.cwl/aligned_bam"
                }
            ],
            "id": "#umi_align.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
